@@ -1,13 +1,10 @@
 /*
  * Convert a GNU gettext .po file to an Apple .strings file.
  *
+ * Copyright © 2020-2024 by OpenPrinting.
  * Copyright 2007-2017 by Apple Inc.
  *
- * These coded instructions, statements, and computer programs are the
- * property of Apple Inc. and are protected by Federal copyright
- * law.  Distribution and use rights are outlined in the file "LICENSE.txt"
- * which should have been included with this file.  If this file is
- * missing or damaged, see the license at "http://www.cups.org/".
+ * Licensed under Apache License v2.0.  See the file "LICENSE" for more information.
  *
  * Usage:
  *
@@ -385,8 +382,6 @@ normalize_string(const char *idstr,	/* I - msgid string */
 	*bufptr++ = (char)0x98;
 	quote     = 1;
       }
-
-      idstr ++;
     }
     else
       *bufptr++ = *idstr;
