@@ -17,6 +17,7 @@
 
 #  include <cups/file.h>
 #  include <stdlib.h>
+#  include <locale.h>
 
 
 //
@@ -471,7 +472,7 @@ class ppdcSource			//// Source File
   int		cond_state,		// Cumulative conditional state
 		*cond_current,		// Current #if state
 		cond_stack[101];	// #if state stack
-
+  struct lconv	*locdata;		// Locale data
 
   ppdcSource(const char *f = 0, cups_file_t *ffp = (cups_file_t *)0);
   ~ppdcSource();
