@@ -1,14 +1,11 @@
 /*
  * File type conversion routines for CUPS.
  *
+ * Copyright © 2020-2024 by OpenPrinting.
  * Copyright 2007-2011 by Apple Inc.
  * Copyright 1997-2007 by Easy Software Products, all rights reserved.
  *
- * These coded instructions, statements, and computer programs are the
- * property of Apple Inc. and are protected by Federal copyright
- * law.  Distribution and use rights are outlined in the file "LICENSE.txt"
- * which should have been included with this file.  If this file is
- * file is missing or damaged, see the license at "http://www.cups.org/".
+ * Licensed under Apache License v2.0.  See the file "LICENSE" for more information.
  */
 
 /*
@@ -16,10 +13,17 @@
  */
 
 #include <cups/string-private.h>
-#include <cups/debug-private.h>
 #include "mime.h"
 
 
+/*
+ * Debug macros that used to be private API...
+ */
+
+#define DEBUG_puts(x)
+#define DEBUG_printf(...)
+
+
 /*
  * Local types...
  */
@@ -61,7 +65,7 @@ mimeAddFilter(mime_t      *mime,	/* I - MIME database */
 		src, src ? src->super : "???", src ? src->type : "???",
 		dst, dst ? dst->super : "???", dst ? dst->type : "???",
 		cost, filter));
-		
+
  /*
   * Range-check the input...
   */
